"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Queue_1 = require("./Queue");
const Redis = require("redis-p");
class QueueStore extends Map {
    constructor(client) {
        super();
        this.client = client;
    }
    connect(conn) {
        if (conn instanceof Redis.RedisClient)
            this.redis = conn;
        else
            this.redis = Redis.createClient(conn);
        return this.redis;
    }
    get(key) {
        let queue = super.get(key);
        if (!queue) {
            queue = new Queue_1.default(this, key);
            this.set(key, queue);
        }
        return queue;
    }
    async start() {
        const keys = await this._scan('playlists.*.np');
        const guilds = keys.map(key => {
            const match = key.match(/playlists\.(\d+)\.np/);
            if (match)
                return match[1];
            throw new Error('error extracting guild ID from playlist');
        });
        for (const guild of guilds)
            this.get(guild).start();
    }
    async _scan(pattern, cursor = '0', keys = []) {
        if (!this.redis)
            throw new Error('attempted to scan without a Redis connection');
        const response = await this.redis.scan(cursor, pattern);
        keys.push(...response[1]);
        if (response[0] === '0')
            return keys;
        return this._scan(pattern, response[0], keys);
    }
}
exports.default = QueueStore;

//# sourceMappingURL=QueueStore.js.map
